[java-identity-provider COMMIT] in /trunk: idp-profile-api/src/main/java/net/shibboleth/idp/profile/ActionSupport.jav...

noreply at shibboleth.net noreply at shibboleth.net
Tue Jul 10 16:11:36 EDT 2012


Author: lajoie
Date: Tue Jul 10 16:11:36 2012
New Revision: 4201

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=4201&view=rev
Log:
Clean up attribute resolution and filtering stages
Add and refactor Event ID constants

Added:
    trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/EventIds.java   (with props)
    trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/profile/SamlEventIds.java
      - copied, changed from r4194, trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/profile/EventIds.java
Modified:
    trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/ActionSupport.java
    trunk/idp-profile-api/src/test/java/net/shibboleth/idp/profile/ActionTestingSupport.java
    trunk/idp-profile-impl/src/main/java/net/shibboleth/idp/profile/impl/FilterAttributes.java
    trunk/idp-profile-impl/src/main/java/net/shibboleth/idp/profile/impl/ResolveAttributes.java
    trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/profile/EventIds.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/AddRelyingPartyConfigurationToProfileRequestContext.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAttributeStatementToAssertion.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAudienceRestrictionToAssertions.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddDoNotCacheConditionToAssertions.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddInResponseToToResponse.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddNotBeforeConditionToAssertions.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddNotOnOrAfterConditionToAssertions.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddResponseShell.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/CheckRequestVersion.java
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAttributeStatementToAssertionTest.java
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/profile/saml1/CheckRequestVersionTest.java

Modified: trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/ActionSupport.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/ActionSupport.java?rev=4201&r1=4200&r2=4201&view=diff
==============================================================================
--- trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/ActionSupport.java (original)
+++ trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/ActionSupport.java Tue Jul 10 16:11:36 2012
@@ -29,24 +29,19 @@
 /** Helper class for {@link org.springframework.webflow.execution.Action} operations. */
 public final class ActionSupport {
 
-    /**
-     * ID of an Event indicating that the action completed successfully and processing should move on to the next step.
-     */
-    public static final String PROCEED_EVENT_ID = "proceed";
-
     /** Constructor. */
     private ActionSupport() {
     }
 
     /**
      * Builds a {@link #PROCEED_EVENT_ID} event with no related attributes.
      * 
      * @param source the source of the event
      * 
      * @return the proceed event
      */
     @Nonnull public static Event buildProceedEvent(@Nonnull final IdentifiableComponent source) {
-        return buildEvent(source, PROCEED_EVENT_ID);
+        return buildEvent(source, EventIds.PROCEED_EVENT_ID);
     }
 
     /**
@@ -29,24 +29,19 @@
 
     /**
-     * Builds a {@link #PROCEED_EVENT_ID} event with no related attributes.
+     * Builds a {@link EventIds#PROCEED_EVENT_ID} event with no related attributes.
      * 
      * @param source the source of the event

Modified: trunk/idp-profile-api/src/test/java/net/shibboleth/idp/profile/ActionTestingSupport.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-profile-api/src/test/java/net/shibboleth/idp/profile/ActionTestingSupport.java?rev=4201&r1=4200&r2=4201&view=diff
==============================================================================
--- trunk/idp-profile-api/src/test/java/net/shibboleth/idp/profile/ActionTestingSupport.java (original)
+++ trunk/idp-profile-api/src/test/java/net/shibboleth/idp/profile/ActionTestingSupport.java Tue Jul 10 16:11:36 2012
@@ -40,13 +40,13 @@
 
     /**
      * Checks that the given event is a proceed event. That is, that the event is not null, that its source is not null,
      * and that its ID is {@link ActionSupport#PROCEED_EVENT_ID}.
      * 
      * @param event the event to check
      */
     public static void assertProceedEvent(Event event) {
         Assert.assertNotNull(event);
         Assert.assertNotNull(event.getSource());
-        Assert.assertEquals(event.getId(), ActionSupport.PROCEED_EVENT_ID);
+        Assert.assertEquals(event.getId(), EventIds.PROCEED_EVENT_ID);
     }
 }
@@ -40,13 +40,13 @@
     /**
      * Checks that the given event is a proceed event. That is, that the event is not null, that its source is not null,
-     * and that its ID is {@link ActionSupport#PROCEED_EVENT_ID}.
+     * and that its ID is {@link EventIds#PROCEED_EVENT_ID}.
      * 
      * @param event the event to check

Modified: trunk/idp-profile-impl/src/main/java/net/shibboleth/idp/profile/impl/FilterAttributes.java

[... 744 lines stripped ...]


More information about the commits mailing list